@@ -45,6 +45,7 @@ class SubtitleEdit;
 class SubtitleModel;
 class TextBasedEdit;
 class GuidesList;
+class KeyframeModelList;
 class TimeRemap;
 
 namespace Mlt {
@@ -69,6 +70,7 @@ class /*KDENLIVECORE_EXPORT*/ Core : public QObject
 
 public:
     friend class KdenliveDoc;
+    friend class ProjectManager;
     Core(const Core &) = delete;
     Core &operator=(const Core &) = delete;
     Core(Core &&) = delete;
@@ -169,9 +171,9 @@ public:
     double getCurrentFps() const;
 
     /** @brief Returns the frame size (width x height) of current profile */
-    QSize getCurrentFrameSize() const;
+    const QSize getCurrentFrameSize() const;
     /** @brief Returns the frame display size (width x height) of current profile */
-    QSize getCurrentFrameDisplaySize() const;
+    const QSize getCurrentFrameDisplaySize() const;
     /** @brief Request project monitor refresh, and restore previously active monitor */
     void refreshProjectMonitorOnce(bool slowUpdate = false);
     /** @brief Request project monitor refresh if current position is inside range*/
@@ -193,8 +195,6 @@ public:
         Note that if you class permits and requires it, you should use the macro PUSH_UNDO instead*/
     void pushUndo(const Fun &undo, const Fun &redo, const QString &text);
     void pushUndo(QUndoCommand *command);
-    /** @brief display a user info/warning message in statusbar */
-    void displayMessage(const QString &message, MessageType type, int timeout = -1);
     /** @brief display timeline selection info in statusbar */
     void displaySelectionMessage(const QString &message);
     /** @brief Clear asset view if itemId is displayed. */
@@ -207,8 +207,8 @@ public:
     int getItemTrack(const ObjectId &id);
     int getItemDuration(const ObjectId &id);
     QSize getItemFrameSize(const ObjectId &id);
-    /** @brief Returns the capabilities of a clip: AudioOnly, VideoOnly or Disabled if both are allowed */
-    PlaylistState::ClipState getItemState(const ObjectId &id);
+    /** @brief Returns the capabilities of a clip: AudioOnly, VideoOnly or Disabled if both are allowed, and its type */
+    std::pair<PlaylistState::ClipState, ClipType::ProducerType> getItemState(const ObjectId &id);
     /** @brief Get a list of video track names with indexes */
     QMap<int, QString> getTrackNames(bool videoOnly);
     /** @brief Returns the composition A track (MLT index / Track id) */
@@ -248,13 +248,11 @@ public:
     bool isMediaCapturing() const;
     /** @brief True if we are currently displaying the record countdown */
     bool captureShowsCountDown() const;
-    MediaCapture *getAudioDevice();
-    /** @brief Returns Project Folder name for capture output location */
-    QString getProjectFolderName();
+    std::shared_ptr<MediaCapture> getAudioDevice();
     /** @brief Returns configured folder for audio capture storage */
     QString getProjectCaptureFolderName();
     /** @brief Returns a timeline clip's bin id */
-    QString getTimelineClipBinId(ObjectId id);
+    const QString getTimelineClipBinId(ObjectId id);
     /** @brief Returns all track ids in timeline */
     std::unordered_set<QString> getAllTimelineTracksId();
     /** @brief Returns a frame duration from a timecode */
@@ -281,7 +279,7 @@ public:
     /** @brief Returns number of audio channels for this project. */
     int audioChannels();
     /** @brief Add guides in the project. */
-    void addGuides(const QList<int> &guides);
+    void addGuides(const QMap<QUuid, QList<int>> &guides);
     /** @brief Temporarily un/plug a list of clips in timeline. */
     void temporaryUnplug(const QList<int> &clipIds, bool hide);
     /** @brief Transcode a video file. */
@@ -326,6 +324,8 @@ public:
                                    const QVariant &value, int ix, QUndoCommand *command);
     void groupAssetMultiKeyframeCommand(const ObjectId &id, const QString &assetId, const QList<QModelIndex> &indexes, GenTime pos,
                                         const QStringList &sourceValues, const QStringList &values, QUndoCommand *command);
+    /** @brief Return all similar keyframe models from the selection */
+    QList<std::shared_ptr<KeyframeModelList>> getGroupKeyframeModels(const ObjectId &id, const QString &assetId);
     /** @brief Remove all effect instances in a group */
     void removeGroupEffect(const ObjectId &id, const QString &assetId, int originalId);
     /** @brief Disable/enable all instance of an effect in a group */
@@ -344,6 +344,10 @@ public:
     void highlightFileInExplorer(QList<QUrl> urls);
     /** @brief When a timeline operation changes the clip under the mouse cursor, inform the qml view */
     void updateHoverItem(const QUuid &uuid);
+    /** @brief Returns true if the asset has {audio, video} */
+    std::pair<bool, bool> assetHasAV(ObjectId id);
+    /** @brief Show an item's effect stack */
+    void showEffectStackFromId(ObjectId owner);
 
 private:
     explicit Core(LinuxPackageType packageType);
@@ -378,7 +382,7 @@ private:
     bool m_guiConstructed = false;
     /** @brief Check that the profile is valid (width is a multiple of 8 and height a multiple of 2 */
     void checkProfileValidity();
-    std::unique_ptr<MediaCapture> m_capture;
+    std::shared_ptr<MediaCapture> m_capture;
     QUrl m_mediaCaptureFile;
     void resetThumbProfile();
 
@@ -393,10 +397,8 @@ public Q_SLOTS:
     const QString actionText(const QString &name);
     /** @brief Add an action to the app's actionCollection */
     void addActionToCollection(const QString &name, QAction *action);
-    /** @brief display a user info/warning message in the project bin */
-    void displayBinMessage(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false,
-                           BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
-    void displayBinLogMessage(const QString &text, int type, const QString logInfo);
+    /** @brief display a user info/warning message in statusbar */
+    void displayMessage(const QString &message, MessageType type, int timeout = -1);
     /** @brief Create small thumbnails for luma used in compositions */
     void buildLumaThumbs(const QStringList &values);
     /** @brief Try to find a display name for the given filename.
@@ -426,6 +428,14 @@ public Q_SLOTS:
     void startRecording(bool showCountdown = false);
     /** @brief Show or hide track head audio rec controls. */
     void monitorAudio(int tid, bool monitor);
+    /** @brief Open a documentation link, showing a warning box first */
+    void openDocumentationLink(const QUrl &link);
+
+private Q_SLOTS:
+    /** @brief display a user info/warning message in the project bin */
+    void displayBinMessagePrivate(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false,
+                                  BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
+    void displayBinLogMessagePrivate(const QString &text, int type, const QString logInfo);
 
 Q_SIGNALS:
     void coreIsReady();
@@ -446,7 +456,7 @@ Q_SIGNALS:
     /** @brief Opening finished, close splash screen */
     void closeSplash();
     /** @brief Trigger an update of the speech models list */
-    void voskModelUpdate(const QStringList models);
+    void speechModelUpdate(SpeechToTextEngine::EngineType engine, const QStringList models);
     /** @brief Update current effect zone */
     void updateEffectZone(const QPoint p, bool withUndo);
     /** @brief The effect stask is about to be deleted, disconnect everything */
@@ -489,4 +499,17 @@ Q_SIGNALS:
     void requestShowBinEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize frameSize, bool showKeyframes);
     /** @brief Save guide categories in document properties */
     void saveGuideCategories();
+    /** @brief When creating a backup file, also save a thumbnail of current timeline */
+    void saveTimelinePreview(const QString &path);
+    /** Enable the built in transform effect for current item */
+    void enableBuildInTransform();
+    /** refresh sam config */
+    void samConfigUpdated();
+    /** Show / hide the automask panel */
+    void switchMaskPanel(bool show);
+    void transcodeProgress(ObjectId id, int progress);
+    /** @brief display a user info/warning message in the project bin */
+    void displayBinMessage(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false,
+                           BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
+    void displayBinLogMessage(const QString &text, int type, const QString logInfo);
 };
