@@ -42,6 +42,11 @@ ClipLoadTask::ClipLoadTask(const ObjectId &owner, const QDomElement &xml, bool t
     , m_thumbOnly(thumbOnly)
 {
     m_description = m_thumbOnly ? i18n("Video thumbs") : i18n("Loading clip");
+    if (!m_xml.isNull()) {
+        if (m_xml.hasAttribute(QStringLiteral("sequenceUuid"))) {
+            m_sequenceUuid = QUuid(m_xml.attribute(QStringLiteral("sequenceUuid")));
+        }
+    }
 }
 
 ClipLoadTask::~ClipLoadTask() {}
@@ -229,7 +234,7 @@ void ClipLoadTask::generateThumbnail(std::shared_ptr<ProjectClip> binClip, std::
             if (m_isCanceled.loadAcquire() || pCore->taskManager.isBlocked()) {
                 return;
             }
-            std::unique_ptr<Mlt::Producer> thumbProd = binClip->getThumbProducer();
+            std::unique_ptr<Mlt::Producer> thumbProd = binClip->getThumbProducer(m_sequenceUuid);
             if (thumbProd && thumbProd->is_valid()) {
                 if (binClip->clipType() != ClipType::Timeline && binClip->clipType() != ClipType::Playlist) {
                     Mlt::Profile *prodProfile = &pCore->thumbProfile();
@@ -266,13 +271,20 @@ void ClipLoadTask::generateThumbnail(std::shared_ptr<ProjectClip> binClip, std::
                                                   Q_ARG(int, m_out), Q_ARG(bool, false));
                     } else if (binClip.get() && !m_isCanceled.loadAcquire()) {
                         // We don't follow m_isCanceled there,
-                        qDebug() << "=== GOT THUMB FOR: " << m_in << "x" << m_out;
+                        qDebug() << "=== GOT THUMB FOR: " << m_in << "x" << m_out << ", UUID: " << m_sequenceUuid << "\nXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
                         ThumbnailCache::get()->storeThumbnail(QString::number(m_owner.itemId), frameNumber, result, false);
                         m_progress = 100;
-                        QMetaObject::invokeMethod(binClip.get(), "setThumbnail", Qt::QueuedConnection, Q_ARG(QImage, result), Q_ARG(int, m_in),
-                                                  Q_ARG(int, m_out), Q_ARG(bool, false));
+                        if (m_sequenceUuid.isNull()) {
+                            QMetaObject::invokeMethod(binClip.get(), "setThumbnail", Qt::QueuedConnection, Q_ARG(QImage, result), Q_ARG(int, m_in),
+                                                      Q_ARG(int, m_out), Q_ARG(bool, false));
+                        } else {
+                            QMetaObject::invokeMethod(binClip.get(), "setSequenceThumbnail", Qt::QueuedConnection, Q_ARG(QImage, result),
+                                                      Q_ARG(QUuid, m_sequenceUuid), Q_ARG(bool, false));
+                        }
                     }
                 }
+            } else {
+                qDebug() << "YYYYYYYYYYYYY\n\nGOT INVALID THUMB PRODUCER FOT CLIP\n\nYYYYYYYYYYYY";
             }
         }
     }
@@ -295,11 +307,9 @@ void ClipLoadTask::run()
                 abort();
                 return;
             }
-            generateThumbnail(binClip, binClip->originalProducer());
-        }
-        if (m_isCanceled.loadAcquire() == 1 || pCore->taskManager.isBlocked()) {
-            abort();
+            generateThumbnail(binClip, binClip->sequenceProducer(m_sequenceUuid));
         }
+        m_progress = 100;
         return;
     }
     Q_EMIT pCore->projectItemModel()->resetPlayOrLoopZone(QString::number(m_owner.itemId));
@@ -395,41 +405,45 @@ void ClipLoadTask::run()
         if (producer) {
             QFile f(resource);
             QDomDocument doc;
-            doc.setContent(&f, false);
-            f.close();
-            if (resource.endsWith(QLatin1String(".kdenlive"))) {
-                QDomElement pl = doc.documentElement().firstChildElement(QStringLiteral("playlist"));
-                if (!pl.isNull()) {
-                    QString offsetData = Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.seekOffset"));
-                    if (offsetData.isEmpty() && Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.version")) == QLatin1String("0.98")) {
-                        offsetData = QStringLiteral("30000");
-                    }
-                    if (!offsetData.isEmpty()) {
-                        bool ok = false;
-                        int offset = offsetData.toInt(&ok);
-                        if (ok) {
-                            qDebug() << " / / / FIXING OFFSET DATA: " << offset;
-                            offset = producer->get_playtime() - offset - 1;
-                            producer->set("out", offset - 1);
-                            producer->set("length", offset);
-                            producer->set("kdenlive:duration", producer->frames_to_time(offset));
+            if (f.open(QIODevice::ReadOnly)) {
+                doc.setContent(&f);
+                f.close();
+                if (resource.endsWith(QLatin1String(".kdenlive"))) {
+                    QDomElement pl = doc.documentElement().firstChildElement(QStringLiteral("playlist"));
+                    if (!pl.isNull()) {
+                        QString offsetData = Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.seekOffset"));
+                        if (offsetData.isEmpty() && Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.version")) == QLatin1String("0.98")) {
+                            offsetData = QStringLiteral("30000");
+                        }
+                        if (!offsetData.isEmpty()) {
+                            bool ok = false;
+                            int offset = offsetData.toInt(&ok);
+                            if (ok) {
+                                qDebug() << " / / / FIXING OFFSET DATA: " << offset;
+                                offset = producer->get_playtime() - offset - 1;
+                                producer->set("out", offset - 1);
+                                producer->set("length", offset);
+                                producer->set("kdenlive:duration", producer->frames_to_time(offset));
+                            }
+                        } else {
+                            qDebug() << "// NO OFFSET DAT FOUND\n\n";
                         }
                     } else {
-                        qDebug() << "// NO OFFSET DAT FOUND\n\n";
+                        qDebug() << "EMPTY PLAYLIST\n----";
+                    }
+                } else if (resource.endsWith(QLatin1String(".mlt"))) {
+                    // Find the last tractor and check if it has a duration
+                    QDomElement tractor = doc.documentElement().lastChildElement(QStringLiteral("tractor"));
+                    QString duration = Xml::getXmlProperty(tractor, QStringLiteral("kdenlive:duration"));
+                    if (!duration.isEmpty()) {
+                        int frames = producer->time_to_frames(duration.toUtf8().constData());
+                        producer->set("out", frames - 1);
+                        producer->set("length", frames);
+                        producer->set("kdenlive:duration", duration.toUtf8().constData());
                     }
-                } else {
-                    qDebug() << ":_______\n______<nEMPTY PLAYLIST\n----";
-                }
-            } else if (resource.endsWith(QLatin1String(".mlt"))) {
-                // Find the last tractor and check if it has a duration
-                QDomElement tractor = doc.documentElement().lastChildElement(QStringLiteral("tractor"));
-                QString duration = Xml::getXmlProperty(tractor, QStringLiteral("kdenlive:duration"));
-                if (!duration.isEmpty()) {
-                    int frames = producer->time_to_frames(duration.toUtf8().constData());
-                    producer->set("out", frames - 1);
-                    producer->set("length", frames);
-                    producer->set("kdenlive:duration", duration.toUtf8().constData());
                 }
+            } else {
+                qDebug() << "==== CANNOT OPEN FILE: " << resource;
             }
         }
         break;
@@ -468,8 +482,15 @@ void ClipLoadTask::run()
                                       Q_ARG(QString, m_errorMessage.isEmpty() ? i18n("Cannot open file %1", resource) : m_errorMessage),
                                       Q_ARG(int, int(KMessageWidget::Warning)));
         }
-        Q_EMIT taskDone();
-        abort();
+
+        if (pCore->currentDoc()->loading) {
+            // We are loading a project with a missing clip, don't delete the clip'
+            QMetaObject::invokeMethod(binClip.get(), "setInvalid", Qt::QueuedConnection);
+            Q_EMIT taskDone();
+        } else {
+            Q_EMIT taskDone();
+            abort();
+        }
         return;
     }
     const QString mltService = producer->get("mlt_service");
@@ -612,7 +633,7 @@ void ClipLoadTask::run()
     double fps = -1;
     bool isVariableFrameRate = false;
     bool seekable = true;
-    bool checkProfile = pCore->bin()->shouldCheckProfile;
+    bool checkProfile = pCore->bin() && pCore->bin()->shouldCheckProfile;
     if (mltService == QLatin1String("xml") || mltService == QLatin1String("consumer")) {
         // MLT playlist, create producer with blank profile to get real profile info
         QString tmpPath = resource;
@@ -637,11 +658,11 @@ void ClipLoadTask::run()
         bool hasVideo = false;
         // Work around MLT freeze on files with cover art
         if (vindex > -1) {
-            QString key = QString("meta.media.%1.stream.frame_rate").arg(vindex);
+            QString key = QStringLiteral("meta.media.%1.stream.frame_rate").arg(vindex);
             fps = producer->get_double(key.toLatin1().constData());
-            key = QString("meta.media.%1.codec.name").arg(vindex);
+            key = QStringLiteral("meta.media.%1.codec.name").arg(vindex);
             QString codec_name = producer->get(key.toLatin1().constData());
-            key = QString("meta.media.%1.codec.frame_rate").arg(vindex);
+            key = QStringLiteral("meta.media.%1.codec.frame_rate").arg(vindex);
             QString frame_rate = producer->get(key.toLatin1().constData());
             if (codec_name == QLatin1String("png") || (codec_name == "mjpeg" && frame_rate == QLatin1String("90000"))) {
                 // Cover art
@@ -652,8 +673,8 @@ void ClipLoadTask::run()
         }
         // Check audio / video
         producer->probe();
-        hasAudio = producer->get_int("video_index") > -1;
-        hasVideo = producer->get_int("audio_index") > -1;
+        hasAudio = producer->get_int("audio_index") > -1;
+        hasVideo = producer->get_int("video_index") > -1;
         if (hasAudio) {
             if (hasVideo) {
                 producer->set("kdenlive:clip_type", 0);
@@ -697,7 +718,7 @@ void ClipLoadTask::run()
             QString adjustedFpsString;
             if (fps > 0) {
                 int integerFps = qRound(fps);
-                adjustedFpsString = QString("-%1fps").arg(integerFps);
+                adjustedFpsString = QStringLiteral("-%1fps").arg(integerFps);
             }
             ClipType::ProducerType cType = type;
             if (cType == ClipType::Unknown) {
@@ -710,6 +731,7 @@ void ClipLoadTask::run()
                     cType = ClipType::AV;
                 }
             }
+            producer->set("_wait_for_transcode", 1);
             QMetaObject::invokeMethod(pCore->bin(), "requestTranscoding", Qt::QueuedConnection, Q_ARG(QString, resource),
                                       Q_ARG(QString, QString::number(m_owner.itemId)), Q_ARG(int, cType), Q_ARG(bool, checkProfile),
                                       Q_ARG(QString, adjustedFpsString),
@@ -734,14 +756,9 @@ void ClipLoadTask::run()
         auto binClip = pCore->projectItemModel()->getClipByBinID(QString::number(m_owner.itemId));
         if (binClip) {
             const QByteArray xmlData = ClipController::producerXml(*producer.get(), true, false);
-            bool replaceProxy = false;
-            bool replaceName = false;
-            if (producer->property_exists("_replaceproxy")) {
-                replaceProxy = true;
-            }
-            if (producer->property_exists("_reloadName")) {
-                replaceName = true;
-            }
+            bool replaceProxy = producer->property_exists("_replaceproxy");
+            bool replaceName = producer->property_exists("_reloadName");
+            bool transcode = producer->property_exists("_wait_for_transcode");
             // Reset produccer to get rid of cached frame
             QReadLocker lock(&pCore->xmlMutex);
             producer.reset(new Mlt::Producer(pCore->getProjectProfile(), "xml-string", xmlData.constData()));
@@ -752,6 +769,9 @@ void ClipLoadTask::run()
             if (replaceName) {
                 producer->set("_reloadName", 1);
             }
+            if (transcode) {
+                producer->set("_wait_for_transcode", 1);
+            }
             QMetaObject::invokeMethod(binClip.get(), "setProducer", Qt::QueuedConnection, Q_ARG(std::shared_ptr<Mlt::Producer>, std::move(producer)),
                                       Q_ARG(bool, true));
             if (checkProfile && !isVariableFrameRate && seekable) {
